import axios from "axios";

const state = {
    regiones: null,
    grupos_de_compra: null,
    region_elegida: null,
    grupo_de_compra_elegido: null,
    rol: null,
};

const mutations = {
    setRegiones(state, { regiones }) {
        state.regiones = regiones;
    },
    setRegionYBarrios(state, { region, grupos_de_compra }) {
        state.region_elegida = region;
        state.grupos_de_compra = grupos_de_compra;
    },
    selectGrupoDeCompra(state, { grupo_de_compra }) {
        state.grupo_de_compra_elegido = grupo_de_compra;
    },
    setRol(state, { rol }) {
        state.rol = rol;
    },
};

const actions = {
    async getRegiones({ commit }) {
        const response = await axios.get("/api/regiones");
        commit('setRegiones', { regiones: response.data });
    },
    async selectRegion({ commit }, { region }) {
        const response = await axios.get(`/api/regiones/${region}`);
        commit('setRegionYBarrios', { region: region, grupos_de_compra: response.data });
    },
    async getRol({ commit }) {
        const response = await axios.get("/user/rol");
        commit('setRol', { rol: response.data.rol });
    }
};

const getters = {
    urlRol() {
        let split = window.location.pathname
            .replace('login', '')
            .split('/')
            .filter(x => x.length);
        return split[0] ?? 'pedido';
    },
    textos() {
        let rol = getters.urlRol();
        switch (rol) {
            case 'pedido':
                return {
                    titulo: "Pedidos MPS",
                    subtitlo: "aplicación de pedidos",
                    password: "Contraseña",
                    ayuda: "Si no la sabés, consultá a la comisión informática",
                    label: "Seleccioná tu región"
                };
            case 'admin':
                return {
                    titulo: "Administración de Pedidos MPS",
                    subtitlo: "administración de pedidos",
                    password: "Contraseña de administración del barrio",
                    ayuda: "Si no la sabés, consultá a la comisión informática",
                    label: "Seleccioná tu región"
                };
            case 'comisiones':
                return {
                    titulo: "Comisiones MPS",
                    subtitlo: "página de comisiones",
                    password: "Contraseña",
                    ayuda: "Si no la sabés, consultá a la comisión informática",
                    label: "Usuario"
                };
            case 'ollas':
                return {
                    titulo: "Ollas MPS",
                    subtitlo: "aplicación de pedidos de ollas",
                    password: "Contraseña de ollas del barrio",
                    ayuda: "Si no la sabés, consultá a la comisión informática",
                    label: "Seleccioná tu región"
                };
            default:
                throw new Error("Url inválida");
        }
    },
    estilos() {
        let rol = getters.urlRol();
        switch (rol) {
            case 'pedido':
                return {
                    fondo: "",
                    texto: "",
                    botones: "danger-dark-button"
                };
            case 'admin':
                return {
                    fondo: "has-background-danger-dark",
                    texto: "has-text-white",
                    botones: "is-dark",
                };
            case 'comisiones':
                return {
                    fondo: "has-background-dark",
                    texto: "has-text-white",
                    botones: "is-white",
                };
            case 'ollas':
                return {
                    fondo: "has-background-dark",
                    texto: "has-text-white",
                    botones: "danger-dark-button",
                };
            default:
                throw new Error("Url inválida");
        }
    },
    opcionesLogin() {
        let rol = getters.urlRol();
        switch (rol) {
            case 'pedido':
                return [
                    { nombre: "Administración", href: "/admin" },
                    { nombre: "Ollas", href: "/ollas" },
                    { nombre: "Comisiones", href: "/comisiones" },
                ];
            case 'admin':
                return [
                    { nombre: "Pedidos", href: "/" },
                    { nombre: "Ollas", href: "/ollas" },
                    { nombre: "Comisiones", href: "/comisiones" },
                ];
            case 'comisiones':
                return [
                    { nombre: "Pedidos", href: "/" },
                    { nombre: "Ollas", href: "/ollas" },
                    { nombre: "Administración", href: "/admin" },
                ];
            case 'ollas':
                return [
                    { nombre: "Pedidos", href: "/" },
                    { nombre: "Administración", href: "/admin" },
                    { nombre: "Comisiones", href: "/comisiones" },
                ];
            default:
                throw new Error("Url inválida");
        }
    },
    nombre() {
        let rol = getters.urlRol();
        switch (rol) {
            case 'pedido':
                return state.grupo_de_compra_elegido;
            case 'admin':
                return `${state.grupo_de_compra_elegido}_admin`;
            case 'ollas':
                return `${state.grupo_de_compra_elegido}_ollas`;
            case 'comisiones':
                return "";
            default:
                throw new Error("Url inválida");
        }
    }
};

export default {
    namespaced: true,
    state,
    mutations,
    actions,
    getters,
};
